@@ -262,8 +262,8 @@ void SPVM_DUMPER_dump_opcode_array(SPVM_COMPILER* compiler, SPVM_OPCODE_ARRAY* o
         case SPVM_OPCODE_C_CODE_LOOKUP_SWITCH: {
           printf(" ");
           
-          printf(" %d %d %d %d %d %d %d\n",
-            opcode.operand0, opcode.operand1, opcode.operand2, opcode.operand3, opcode.operand4, opcode.operand5, opcode.operand6);
+          printf(" %d %d %d\n",
+            opcode.operand0, opcode.operand1, opcode.operand2);
           
           int32_t case_length = opcode.operand2;
           
@@ -273,8 +273,8 @@ void SPVM_DUMPER_dump_opcode_array(SPVM_COMPILER* compiler, SPVM_OPCODE_ARRAY* o
             for (j = 0; j < case_length; j++) {
               i++;
               SPVM_OPCODE opcode = opcode_array->values[i];
-              printf("        [%" PRId32 "] %s %d %d %d %d %d %d %d\n",
-                i, SPVM_OPCODE_C_CODE_NAMES[opcode.code], opcode.operand0, opcode.operand1, opcode.operand2, opcode.operand3, opcode.operand4, opcode.operand5, opcode.operand6);
+              printf("        [%" PRId32 "] %s %d %d %d\n",
+                i, SPVM_OPCODE_C_CODE_NAMES[opcode.code], opcode.operand0, opcode.operand1, opcode.operand2);
             }
           }
           
@@ -283,8 +283,8 @@ void SPVM_DUMPER_dump_opcode_array(SPVM_COMPILER* compiler, SPVM_OPCODE_ARRAY* o
         default :
         // Have seven operands
         {
-          printf(" %d %d %d %d %d %d %d\n",
-            opcode.operand0, opcode.operand1, opcode.operand2, opcode.operand3, opcode.operand4, opcode.operand5, opcode.operand6);
+          printf(" %d %d %d\n",
+            opcode.operand0, opcode.operand1, opcode.operand2);
           break;
         }
       }
