@@ -515,46 +515,6 @@ SPVM_OP* SPVM_OP_build_sub_setter(SPVM_COMPILER* compiler, SPVM_OP* op_package,
   return op_sub;
 }
 
-SPVM_OP* SPVM_OP_build_default_new(SPVM_COMPILER* compiler, SPVM_OP* op_type) {
-  
-  // New op
-  SPVM_OP* op_new = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_NEW, op_type->file, op_type->line);
-  
-  // New type
-  SPVM_OP* op_type_new = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_TYPE, op_type->file, op_type->line);
-  op_type_new->uv.type = op_type->uv.type;
-  SPVM_OP_insert_child(compiler, op_new, op_new->last, op_type_new);
-  
-  SPVM_DYNAMIC_ARRAY_push(compiler->op_types, op_type_new);
-  
-  // Return
-  SPVM_OP* op_return = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_RETURN, op_type->file, op_type->line);
-  SPVM_OP_insert_child(compiler, op_return, op_return->last, op_new);
-  
-  // Statements
-  SPVM_OP* op_list_statements = SPVM_OP_new_op_list(compiler, op_type->file, op_type->line);
-  SPVM_OP_insert_child(compiler, op_list_statements, op_list_statements->last, op_return);
-  
-  // Block
-  SPVM_OP* op_block = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_BLOCK, op_type->file, op_type->line);
-  SPVM_OP_insert_child(compiler, op_block, op_block->last, op_list_statements);
-  
-  // sub
-  SPVM_OP* op_sub = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_SUB, op_type->file, op_type->line);
-  op_sub->file = op_type->file;
-  op_sub->line = op_type->line;
-  
-  // Type
-  SPVM_OP* op_return_type = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_TYPE, op_type->file, op_type->line);
-  op_return_type->uv.type = op_type->uv.type;
-  SPVM_DYNAMIC_ARRAY_push(compiler->op_types, op_return_type);
-  
-  // Build subroutine
-  op_sub = SPVM_OP_build_sub(compiler, op_sub, op_type, NULL, NULL, op_return_type, op_block);
-  
-  return op_sub;
-}
-
 SPVM_OP* SPVM_OP_get_parent(SPVM_COMPILER* compiler, SPVM_OP* op_target) {
   (void)compiler;
   
@@ -1694,20 +1654,6 @@ SPVM_OP* SPVM_OP_build_package(SPVM_COMPILER* compiler, SPVM_OP* op_package, SPV
       }
     }
     
-    // Add default constructor
-    const char* sub_abs_name_new = SPVM_OP_create_abs_name(compiler, package_name, "new");
-    SPVM_OP* found_op_sub_new = SPVM_HASH_search(compiler->op_sub_symtable, sub_abs_name_new, strlen(sub_abs_name_new));
-    if (!found_op_sub_new) {
-      SPVM_OP* op_sub_new = SPVM_OP_build_default_new(compiler, package->op_type);
-      SPVM_SUB* sub_new = op_sub_new->uv.sub;
-      sub_new->abs_name = sub_abs_name_new;
-      sub_new->file_name = op_package->file;
-      sub_new->op_package = op_package;
-      
-      SPVM_DYNAMIC_ARRAY_push(compiler->op_subs, op_sub_new);
-      SPVM_HASH_insert(compiler->op_sub_symtable, sub_abs_name_new, strlen(sub_abs_name_new), op_sub_new);
-    }
-    
     // Add op fields
     package->op_fields = op_fields;
     
