@@ -343,6 +343,15 @@ const char* const SPVM_OPCODE_C_CODE_NAMES[] = {
   "IF_CROAK_CATCH",
   "IF_CROAK_RETURN",
   "SET_CROAK_FLAG_TRUE",
+  "MOVE_BYTE",
+  "MOVE_SHORT",
+  "MOVE_INT",
+  "MOVE_LONG",
+  "MOVE_FLOAT",
+  "MOVE_DOUBLE",
+  "MOVE_OBJECT",
+  "PUSH_AUTO_DEC_REF_COUNT",
+  "LEAVE_SCOPE",
 };
 
 SPVM_OPCODE* SPVM_OPCODE_new(SPVM_COMPILER* compiler) {
