@@ -343,6 +343,15 @@ enum {
   SPVM_OPCODE_C_CODE_IF_CROAK_CATCH,
   SPVM_OPCODE_C_CODE_IF_CROAK_RETURN,
   SPVM_OPCODE_C_CODE_SET_CROAK_FLAG_TRUE,
+  SPVM_OPCODE_C_CODE_MOVE_BYTE,
+  SPVM_OPCODE_C_CODE_MOVE_SHORT,
+  SPVM_OPCODE_C_CODE_MOVE_INT,
+  SPVM_OPCODE_C_CODE_MOVE_LONG,
+  SPVM_OPCODE_C_CODE_MOVE_FLOAT,
+  SPVM_OPCODE_C_CODE_MOVE_DOUBLE,
+  SPVM_OPCODE_C_CODE_MOVE_OBJECT,
+  SPVM_OPCODE_C_CODE_PUSH_AUTO_DEC_REF_COUNT,
+  SPVM_OPCODE_C_CODE_LEAVE_SCOPE,
 };
 
 enum {
