@@ -108,6 +108,12 @@ SPVM_API_VALUE SPVM_RUNTIME_call_sub(SPVM_API* api, int32_t sub_id, SPVM_API_VAL
   // Call subroutine argument stack top
   int32_t call_sub_arg_stack_top = -1;
   
+  // Auto decrement reference count variable index stack
+  SPVM_API_OBJECT* auto_dec_ref_count_stack[65535];
+  
+  // Auto decrement reference count variable index stack top
+  int32_t auto_dec_ref_count_stack_top = -1;
+  
   // Condition flag
   register int32_t condition_flag = 0;
   
@@ -117,9 +123,6 @@ SPVM_API_VALUE SPVM_RUNTIME_call_sub(SPVM_API* api, int32_t sub_id, SPVM_API_VAL
   // Croak flag
   int32_t croak_flag = 0;
   
-  // Initialize variables
-  memset(vars, 0, sizeof(SPVM_API_VALUE) * sub_mys_length);
-
   // Copy arguments
   memcpy(vars, args, args_length * sizeof(SPVM_API_VALUE));
 
@@ -1102,6 +1105,26 @@ SPVM_API_VALUE SPVM_RUNTIME_call_sub(SPVM_API* api, int32_t sub_id, SPVM_API_VAL
         }
         break;
       }
+      case SPVM_OPCODE_C_CODE_PUSH_AUTO_DEC_REF_COUNT: {
+        auto_dec_ref_count_stack_top++;
+        auto_dec_ref_count_stack[auto_dec_ref_count_stack_top] = opcode->operand0;
+        break;
+      }
+      case SPVM_OPCODE_C_CODE_LEAVE_SCOPE: {
+        int32_t auto_dec_ref_count_stack_base = opcode->operand0;
+        int32_t index;
+        for (index = auto_dec_ref_count_stack_base; index <= auto_dec_ref_count_stack_top; index++) {
+          int32_t var_index = auto_dec_ref_count_stack[index];
+          
+          if (*(SPVM_API_OBJECT**)&vars[var_index] != NULL) {
+            api->dec_ref_count(api, *(SPVM_API_OBJECT**)&vars[var_index]);
+          }
+        }
+        
+        auto_dec_ref_count_stack_top = auto_dec_ref_count_stack_base - 1;
+        
+        break;
+      }
       case SPVM_OPCODE_C_CODE_NEW_OBJECT: {
         // Get subroutine ID
         int32_t type_id = opcode->operand1;
@@ -1851,6 +1874,13 @@ SPVM_API_VALUE SPVM_RUNTIME_call_sub(SPVM_API* api, int32_t sub_id, SPVM_API_VAL
         // Set return value
         if (!constant_pool_sub->is_void) {
           return_value = vars[opcode->operand0];
+          
+          // Increment ref count of return value not to release by decrement
+          if (sub_return_type_code > SPVM_TYPE_C_CODE_DOUBLE) {
+            if (return_value.object_value != NULL) {
+              SPVM_INLINE_INC_REF_COUNT(return_value.object_value);
+            }
+          }
         }
         
         goto label_SPVM_OPCODE_C_CODE_RETURN;
@@ -1915,14 +1945,8 @@ SPVM_API_VALUE SPVM_RUNTIME_call_sub(SPVM_API* api, int32_t sub_id, SPVM_API_VAL
 
   label_SPVM_OPCODE_C_CODE_RETURN: {
     
-    // Increment ref count of return value not to release by decrement
-    if (sub_return_type_code > SPVM_TYPE_C_CODE_DOUBLE) {
-      if (return_value.object_value != NULL) {
-        SPVM_INLINE_INC_REF_COUNT(return_value.object_value);
-      }
-    }
-    
     // Decrement my vars
+    /*
     {
       int32_t i;
       for (i = 0; i < sub_object_mys_length; i++) {
@@ -1939,16 +1963,28 @@ SPVM_API_VALUE SPVM_RUNTIME_call_sub(SPVM_API* api, int32_t sub_id, SPVM_API_VAL
         }
       }
     }
+    */
     
-    // Decrement ref count of return value
-    if (sub_return_type_code > SPVM_TYPE_C_CODE_DOUBLE) {
-      if (return_value.object_value != NULL) {
-        SPVM_INLINE_DEC_REF_COUNT_ONLY(return_value.object_value);
+    {
+      int32_t index;
+      for (index = 0; index <= auto_dec_ref_count_stack_top; index++) {
+        int32_t var_index = auto_dec_ref_count_stack[index];
+        
+        if (*(SPVM_API_OBJECT**)&vars[var_index] != NULL) {
+          api->dec_ref_count(api, *(SPVM_API_OBJECT**)&vars[var_index]);
+        }
       }
     }
     
     // Croak
     if (!croak_flag) {
+      // Decrement ref count of return value
+      if (sub_return_type_code > SPVM_TYPE_C_CODE_DOUBLE) {
+        if (return_value.object_value != NULL) {
+          SPVM_INLINE_DEC_REF_COUNT_ONLY(return_value.object_value);
+        }
+      }
+      
       SPVM_INLINE_SET_EXCEPTION_NULL();
     }
     
